### Name: impute.marker
### Title: Imputation of missing marker values in QTL progeny
### Aliases: impute.marker impute.marker.matrix
### Keywords: regression models

### ** Examples

m <- c(1,1,2,2,1,NA,1,2,NA,1,1,NA)
d <- c(10,11,9,10,21,28,13,6,5,12,7)
impute.marker(m,d,map.function="haldane",marker.values=1:2)

# simulated backcross progeny with ~5% missing marker genotypes
set.seed(1234)
marker.pos <- seq(5,105,by=10)
qtldata200 <- sim.bc.progeny(n=200,Vp=c(0.1,0.2,0.3,0.15,0.25)/2,
      map.pos=list(chrom=rep(1:2,rep(length(marker.pos),2)),
      pos=rep(marker.pos,2)),qtl.pos=list(chrom=rep(1:2,c(3,2)),
                                pos=c(40,50,80,30,55)))
x.mv <- qtldata200$x
num.missing <- round(0.05*length(qtldata200$x))
mv.pos <- sample(1:length(c(qtldata200$x)),size=num.missing,replace=FALSE)
x.mv[mv.pos] <- NA
c1.cols <- 1:11
x200c1.imp10 <- impute.marker.matrix(x.mv[,c1.cols],d=diff(marker.pos),
                                num.imputations=10)
c2.cols <- 12:22
x200c2.imp10 <- impute.marker.matrix(x.mv[,c2.cols],d=diff(marker.pos),
                                num.imputations=10)
x200 <- cbind(x200c1.imp10,x200c2.imp10)



